PitelConfigure class

Constructors

PitelConfigure()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

apiKey String
no setter
apiMobileUrl String
no setter
apiPushUrl String
no setter
domainPortal String
no setter
domainSDK String
no setter
isDebug bool
getter/setter pair
token String
no setter

Static Methods

setApiKey(String key) → void