MyLogPrinter class

Constructors

MyLogPrinter(String currentWorkingDirectory)

Properties

colors ↔ bool
getter/setter pair
currentWorkingDirectory ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

destroy() → Future<void>
inherited
init() → Future<void>
inherited
log(LogEvent event) → List<String>
Is called every time a new LogEvent is sent and handles printing or storing the message.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

levelColors → Map<Level, AnsiColor>
final