RTCSession class

Inheritance

Constructors

RTCSession(PitelUA? ua)

Properties

causes → Type
User API
no setter
connection → RTCPeerConnection?
no setter
contact → String?
no setter
data ↔ Map<String, dynamic>?
getter/setter pair
direction → String?
no setter
dtmfFuture ↔ Future<void>
getter/setter pair
dtmfSender → RTCDTMFSender
no setter
end_time → DateTime?
no setter
hashCode → int
The hash code for this object.
no setterinherited
id → String?
no setter
listeners ↔ Map<Type, List>
getter/setter pairinherited
local_identity → NameAddrHeader?
no setter
receiveRequest ↔ dynamic Function(IncomingRequest)
getter/setter pair
remote_identity → NameAddrHeader?
no setter
request → dynamic
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
start_time → DateTime?
no setter
status → int?
no setter
ua → PitelUA?
no setter

Methods

addAllEventHandlers(EventManager other) → void
add all event handlers from an other instance of EventManager to this one.
inherited
answer(Map<String, dynamic> options) → void
Answer the call.
connect(dynamic target, [Map<String, dynamic>? options, InitSuccessCallback? initCallback]) → void
emit<T extends EventType>(T event) → void
send the supplied event to all of the listeners that are subscribed to that EventType
inherited
hasListeners(EventType event) → bool
returns true if there are any listeners associated with the EventType for this instance of EventManager
inherited
hold([Map<String, dynamic>? options, Function? done]) → bool
Hold
init_incoming(IncomingRequest request, [dynamic initCallback(RTCSession)?]) → void
isEnded() → bool
isEstablished() → bool
isInProgress() → bool
isMuted() → Map<String, dynamic>
isOnHold() → Map<String, dynamic>
mute([bool audio = true, bool video = true]) → void
Mute
newDTMF(String originator, DTMF dtmf, dynamic request) → void
newInfo(String originator, Info info, dynamic request) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
on<T extends EventType>(T eventType, void listener(T event)) → void
call "on" to subscribe to events of a particular type
inherited
onDialogError() → void
onRequestTimeout() → void
onTransportError() → void
Session Callbacks
refer(dynamic target, [Map<String, dynamic>? options]) → ReferSubscriber?
Refer
remove<T extends EventType>(T eventType, void listener(T event)?) → void
inherited
renegotiate([Map<String, dynamic>? options, Function? done]) → Future<bool>
sendDTMF(dynamic tones, [Map<String, dynamic>? options]) → void
tones may be a single character or a string of dtmf digits
sendInfo(String contentType, String body, Map<String, dynamic> options) → void
sendRequest(SipMethod method, [Map<String, dynamic>? options]) → OutgoingRequest
Send a generic in-dialog Request
terminate([Map<String, dynamic>? options]) → void
Terminate the call.
toString() → String
A string representation of this object.
inherited
unhold([Map<String, dynamic>? options, Function? done]) → bool
unmute([bool audio = true, bool video = true]) → void
Unmute

Operators

operator ==(Object other) → bool
The equality operator.
inherited