WebSocketInterface class

Implemented types

Constructors

WebSocketInterface(String url, [WebSocketSettings? webSocketSettings])

Properties

hashCode → int
The hash code for this object.
no setterinherited
onconnect ↔ void Function()?
getter/setter pairoverride
ondata ↔ void Function(dynamic data)?
getter/setter pairoverride
ondisconnect ↔ void Function(WebSocketInterface socket, bool error, int? closeCode, String? reason)?
getter/setter pairoverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sip_uri → String?
no setteroverride
status ↔ int?
getter/setter pair
url → String?
no setteroverride
via_transport ↔ String
getter/setter pairoverride
weight ↔ int?
getter/setter pair

Methods

connect() → void
override
disconnect() → void
override
isConnected() → bool
isConnecting() → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
send(dynamic message) → bool
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited