URI class

-param {String} scheme -param {String} user -param {String} host -param {String} port -param {Object} parameters -param {Object} headers

Constructors

URI(String? scheme, String? user, String? host, [int? port, Map? parameters, Map? headers])

Properties

hashCode → int
The hash code for this object.
no setterinherited
host ↔ String
getter/setter pair
port ↔ int?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scheme ↔ String
getter/setter pair
user ↔ String?
getter/setter pair

Methods

clearHeaders() → void
clearParams() → void
clone() → URI
deleteHeader(String header) → dynamic
deleteParam(String parameter) → dynamic
getHeader(String? name) → dynamic
getParam(String? key) → dynamic
hasHeader(String? name) → bool
hasParam(String? key) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setHeader(String name, dynamic value) → void
setParam(String? key, dynamic value) → void
toAor({bool showPort = false}) → String
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

parse(String uri) → dynamic
Parse the given string and returns a DartSIP.URI instance or null if it is an invalid URI.