MobileApiService class
- Inheritance
-
- Object
- HttpService
- MobileApiService
Constructors
Properties
- domain → String
-
no setteroverride
- dynamicDomain ← String
-
no getter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
delete(
String api, Map< String, dynamic> ? headers, Map<String, dynamic> body) → Future<Map< String, dynamic> > -
inherited
-
get(
String api, Map< String, dynamic> ? headers, Map<String, dynamic> ? params) → Future<Map< String, dynamic> > -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
post(
String api, Map< String, dynamic> ? headers, Map<String, dynamic> body) → Future<Map< String, dynamic> > -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited